==> hooks-1.1.8.tgz: package/es/hooks/use-visitor.js <==
import { useEffect, useRef } from "react";
export function useVisitor(param, age) {
  var timer = useRef();
  var onPrevEvent = useRef(param);
  var onEvent = function onEvent(event, e) {
    if (timer.current) {
      clearTimeout(timer.current);
    }
    timer.current = setTimeout(function () {
      var _onPrevEvent$current$, _onPrevEvent$current;
      var data = e.arguments[0];
      (_onPrevEvent$current$ = (_onPrevEvent$current = onPrevEvent.current)[event]) === null || _onPrevEvent$current$ === void 0 ? void 0 : _onPrevEvent$current$.call(_onPrevEvent$current, data);
    }, 5);
  };
  var onPushStatePrev = function onPushStatePrev(e) {
    onEvent('onPushState', e);
  };
  var onReplaceStatePrev = function onReplaceStatePrev(e) {
    onEvent('onReplaceState', e);
  };
  useEffect(function () {
    onPrevEvent.current = param;
  }, [age]);
  var _wr = function _wr(type) {
    var origin = window.history[type];
    return function () {
      // @ts-ignore
      var newEvent = origin.apply(this, arguments);
      var e = new Event(type);
      e.arguments = arguments;
      window.dispatchEvent(e);
      return newEvent;
    };
  };
  var register = function register() {
    window.history.pushState = _wr('pushState');
    window.history.replaceState = _wr('replaceState');
    window.addEventListener('popstate', onPushStatePrev);
    window.addEventListener('pushState', onPushStatePrev);
    window.addEventListener('replaceState', onReplaceStatePrev);
  };
  var unregister = function unregister() {
    window.removeEventListener('popstate', onPushStatePrev);
    window.removeEventListener('pushState', onPushStatePrev);
    window.removeEventListener('replaceState', onReplaceStatePrev);
  };
  useEffect(function () {
    register();
    return function () {
      unregister();
    };
  }, []);
}

==> hooks-1.1.10.tgz: package/es/hooks/use-visitor.js <==
import { useEffect, useRef } from "react";
export function useVisitor(param, age) {
  var timer = useRef();
  var onPrevEvent = useRef(param);
  var onEvent = function onEvent(event, e) {
    if (timer.current) {
      clearTimeout(timer.current);
    }
    timer.current = setTimeout(function () {
      var _onPrevEvent$current$, _onPrevEvent$current;
      var data = undefined;
      if (e && (e === null || e === void 0 ? void 0 : e.arguments[0])) {
        data = e === null || e === void 0 ? void 0 : e.arguments[0];
      }
      (_onPrevEvent$current$ = (_onPrevEvent$current = onPrevEvent.current)[event]) === null || _onPrevEvent$current$ === void 0 ? void 0 : _onPrevEvent$current$.call(_onPrevEvent$current, data);
    }, 5);
  };
  var onPushStatePrev = function onPushStatePrev(e) {
    onEvent('onPushState', e);
  };
  var onReplaceStatePrev = function onReplaceStatePrev(e) {
    onEvent('onReplaceState', e);
  };
  useEffect(function () {
    onPrevEvent.current = param;
  }, [age]);
  var _wr = function _wr(type) {
    var origin = window.history[type];
    return function () {
      // @ts-ignore
      var newEvent = origin.apply(this, arguments);
      var e = new Event(type);
      e.arguments = arguments;
      window.dispatchEvent(e);
      return newEvent;
    };
  };
  var register = function register() {
    window.history.pushState = _wr('pushState');
    window.history.replaceState = _wr('replaceState');
    window.addEventListener('popstate', onPushStatePrev);
    window.addEventListener('pushState', onPushStatePrev);
    window.addEventListener('replaceState', onReplaceStatePrev);
  };
  var unregister = function unregister() {
    window.removeEventListener('popstate', onPushStatePrev);
    window.removeEventListener('pushState', onPushStatePrev);
    window.removeEventListener('replaceState', onReplaceStatePrev);
  };
  useEffect(function () {
    register();
    return function () {
      unregister();
    };
  }, []);
}
